14.112. cdist-type__prometheus_alertmanager(7) — cdist 4.8.1 documentation

# 14.112. cdist-type__prometheus_alertmanager(7)

## 14.112.1. NAME

cdist-type__prometheus_alertmanager - install Alertmanager

## 14.112.2. DESCRIPTION

Install and configure Prometheus Alertmanager (https://prometheus.io/docs/alerting/alertmanager/).

This type create a daemontools-compatible service directory under /service/prometheus. Daemontools (or something compatible) must be installed (in particular, the command svc must be executable).

## 14.112.3. REQUIRED PARAMETERS

config
  Alertmanager configuration file. It will be saved as /etc/alertmanager/alertmanager.yml on the target.
listen-address
  Passed as web.listen-address.

## 14.112.4. OPTIONAL PARAMETERS

storage-path
  Where to put data. Default: /data/alertmanager. (Directory will be created if needed.)

## 14.112.5. BOOLEAN PARAMETERS

None

## 14.112.6. EXAMPLES

    ALERTPORT=9093

    __daemontools
    __golang_from_vendor --version 1.8.1  # required for prometheus and many exporters

    require="__daemontools __golang_from_vendor" __prometheus_alertmanager \
      --with-daemontools \
      --config "$__manifest/files/alertmanager.yml" \
      --storage-path /data/alertmanager \
      --listen-address "[::]:$ALERTPORT"

## 14.112.7. SEE ALSO

cdist-type__prometheus_server(7), cdist-type__daemontools(7), Prometheus alerting documentation: https://prometheus.io/docs/alerting/overview/

## 14.112.8. AUTHORS

Kamila Součková <kamila--@--ksp.sk>

## 14.112.9. COPYING

Copyright (C) 2017 Kamila Součková. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.